==> clean900_2.0.1-7.tar.gz: clean900-2.0.1/usr/bin/clean900/signal.sh <==
#!/bin/sh
#signal.sh
#version 2.0.0
#by incrys for www.maemomeego.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

imei=`dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei |grep string |awk '$1 == "string"' |awk -F '"' '{print $2}'`
imsi=`dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.SIM /com/nokia/phone/SIM Phone.Sim.get_imsi |grep string |awk '$1 == "string"' |awk -F '"' '{print $2}'`

dbus-send --system --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_signal_strength > /tmp/signal.txt
percento=`sed -n '2p' /tmp/signal.txt |awk '$1 == "byte" {print $2}'`
db=`sed -n '3p' /tmp/signal.txt |awk '$1 == "byte" {print $2}'`

dbus-send --system --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_radio_access_technology > /tmp/signal2.txt
twoG=`sed -n '2p' /tmp/signal2.txt |awk '$1 == "byte" {print $2}'`

if [ "$twoG" -eq "2" ]
	then
		signal=`echo "3G or Dual"`
	else
		signal=`echo "2G"`
fi

adapter=`dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F'"' '/at/ {print $2}'`

hciconfig > /tmp/address.txt
ind=`sed -n '2p' /tmp/address.txt |awk '/dr/ {print $3}'`

dbus-send --print-reply --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.get_extension_property string:volume > /tmp/volume.txt
vol=`sed -n '3p' /tmp/volume.txt |awk '$1 == "variant" {print $3}'`

ifconfig > /tmp/wlan0.txt
wlan=`sed -n '16p' /tmp/wlan0.txt |awk '/addr/ {print $5}'`

cod="
IMEI\				=	$imei\		
IMSI\				=	$imsi\		
Cellular Signal\	=	$percento\% \/ $db bBm\			
Current Mode\	=	$signal\		
Bluetooth\		=	$adapter\		
BT Address\		=	$ind\		
Get Volume\		=	$vol\%	
MAC WLAN\		=	$wlan"		

zenity --info --title="Partition Name" --text="$cod"

==> clean900_2.0.1-9.9.tar.gz: clean900-2.0.1/usr/bin/clean900/signal.sh <==
#!/bin/sh
#signal.sh
#version 2.0.1-9.8
#by incrys for www.smartphonetab.net

if [ `id -u` != 0 ] ; then
    exec root <<EOF
exec sh $0 $*
EOF
	exit $?
fi 

imei=`dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.SIM /com/nokia/phone/SIM/security Phone.Sim.Security.get_imei |grep string |awk '$1 == "string"' |awk -F '"' '{print $2}'`
imsi=`dbus-send --system --type=method_call --print-reply --dest=com.nokia.phone.SIM /com/nokia/phone/SIM Phone.Sim.get_imsi |grep string |awk '$1 == "string"' |awk -F '"' '{print $2}'`

dbus-send --system --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_signal_strength > /tmp/signal.txt
percento=`sed -n '2p' /tmp/signal.txt |awk '$1 == "byte" {print $2}'`
db=`sed -n '3p' /tmp/signal.txt |awk '$1 == "byte" {print $2}'`

dbus-send --system --print-reply --dest=com.nokia.phone.net /com/nokia/phone/net Phone.Net.get_radio_access_technology > /tmp/signal2.txt
twoG=`sed -n '2p' /tmp/signal2.txt |awk '$1 == "byte" {print $2}'`

if [ "$twoG" -eq "2" ]
	then
		signal=`echo "3G or Dual"`
	else
		signal=`echo "2G"`
fi

adapter=`dbus-send --system --print-reply --dest=org.bluez / org.bluez.Manager.ListAdapters | awk -F'"' '/at/ {print $2}'`

hciconfig > /tmp/address.txt
ind=`sed -n '2p' /tmp/address.txt |awk '/dr/ {print $3}'`

dbus-send --print-reply --type=method_call --dest=com.nokia.mafw.renderer.Mafw-Gst-Renderer-Plugin.gstrenderer /com/nokia/mafw/renderer/gstrenderer com.nokia.mafw.extension.get_extension_property string:volume > /tmp/volume.txt
vol=`sed -n '3p' /tmp/volume.txt |awk '$1 == "variant" {print $3}'`

ifconfig > /tmp/wlan0.txt
wlan=`sed -n '16p' /tmp/wlan0.txt |awk '/addr/ {print $5}'`

cod="
IMEI\				=	$imei\		
IMSI\				=	$imsi\		
Cellular Signal\	=	$percento\% \/ $db bBm\			
Current Mode\	=	$signal\		
Bluetooth\		=	$adapter\		
BT Address\		=	$ind\		
Get Volume\		=	$vol\%	
MAC WLAN\		=	$wlan"		

zenity --info --title="Partition Name" --text="$cod"
